@@ -1,6 +1,6 @@
 #' @title EdSurvey Mixed-Effects Model
 #' 
-#' @description Fits a linear or logistic weighted mixed-effects model.
+#' @description Fits a linear weighted mixed-effects model.
 #' 
 #' @param formula a \ifelse{latex}{\code{formula}}{\code{\link[stats]{formula}}}
 #'                for the multilevel regression or mixed model. See Examples and the vignette titled 
@@ -12,9 +12,6 @@
 #'                for a subject scale or subscale (one of the names shown by
 #'                \code{\link{showPlausibleValues}}), then that subject scale
 #'                or subscale is used.
-#'                
-#'                For logistic models, we recommend using the \code{I()} function 
-#'                   to define the level used for success. (See Examples.)
 #' @param data an \code{edsurvey.data.frame} or a \code{light.edsurvey.data.frame}
 #' @param weightVars character vector indicating weight variables for
 #'                   corresponding levels to use. The \code{weightVar} must be
@@ -38,15 +35,8 @@
 #'                          an \code{edsurvey.data.frame} to subset the data.
 #'                          Use \code{print} on an \code{edsurvey.data.frame}
 #'                          to see the default conditions.
-#' @param tolerance a numeric value to indicate how accurate the result is.
-#'                  See Details for more information. Defaults to 0.01.
-#' @param nQuad an integer to indicate the number of quadrature points in
-#'              adaptive quadrature process. See documentation of
-#'              \ifelse{latex}{\code{WeMix::mix}}{\code{\link[WeMix]{mix}}} 
-#'              for more details on how \code{nQuad} affects
-#'              the estimation. If no \code{nQuad} is set, function will start with 
-#'              \code{nQuad = 5} and increase until a stable result is reached. See details for 
-#'              further discussion. 
+#' @param tolerance depreciated, no effect
+#' @param nQuad depreciated, no effect
 #' @param verbose an integer; when set to \code{1}, it will print out
 #'                the brief progress of the function \code{mix.sdf}.
 #'                Users can use these traced messages for further diagnosis.
@@ -54,31 +44,52 @@
 #'                out the detailed progress, including temporary estimates
 #'                   during the optimization. Defaults to \code{0}, which 
 #'                   will run the function without output. 
-#' @param family an element of \ifelse{latex}{\code{family}}{\code{\link[stats]{family}}} class; optionally used 
-#'                to specify generalized linear mixed models.
-#'                Defaults to \code{NULL}, which runs mixed linear regression models. Another 
-#'                family option is \code{binomial(link="logit")} to run binomial mixed models.
+#' @param family this argument is depreciated; please use the \code{WeMix}
+#'               package's \code{mix} function directly for binomial models.
 #' @param centerGroup a list in which the name of each element is the name of the aggregation level, 
 #' and the element is a formula of variable names to be group mean centered. For example, to group mean center
 #'  gender and age within the group student: \code{list("student"= ~gender+age)}. Defaults to \code{NULL}, which means 
-#'  predictors are not adjusted by group centering. See Examples in \ifelse{latex}{\code{mix}}{\code{\link[WeMix]{mix}}}.
+#'  predictors are not adjusted by group centering. See Examples in the \code{WeMix} function \ifelse{latex}{\code{mix}}{\code{\link[WeMix]{mix}}}.
 #' @param centerGrand  a formula of variable names to be grand mean centered. For example, to center the 
 #' variable education by overall mean of education: \code{~education}. Defaults to \code{NULL}, which means predictors
 #' are not adjusted by grand centering.
-#' @param fast a logical value; when set to \code{TRUE}, use  c++ function for faster result. Defaults to \code{FALSE}.
+#' @param fast depreciated, no effect
 #'  
 #' @param ... other potential arguments to be used in \ifelse{latex}{\code{mix}}{\code{\link[WeMix]{mix}}} 
+#'
+#' @details 
+#' This function uses the \code{mix} call in the \code{WeMix} package to fit mixed models.
+#' When the outcome does not have plausible values, the variance estimator directly from
+#' the \code{mix} function is used; these account for covariance at the top level
+#' of the model specified by the user.
+#'
+#' When the outcome has plausible values, the coefficients are estimated in the same
+#' way as in \code{lm.sdf}, that is, averaged across the plausible values.
+#' In addition, the variance of the coefficients is estimated
+#' as the sum of the variance estimate from the \code{mix} function and the
+#' imputation variance. The formula for the imputation variance is, again, the same
+#' as for \code{lm.sdf},
+#' with the same estimators as in the vignette titled
+#' \href{https://www.air.org/sites/default/files/EdSurvey-Statistics.pdf}{\emph{Statistical Methods Used in EdSurvey}}.
+#' In the section
+#' \dQuote{Estimation of Standard Errors of Weighted Means When Plausible Values Are Present, Using the Jackknife Method}
+#' in the formula for \eqn{V_{imp}}, the variance
+#' and estimates of the variance components are estimated with the same formulas as
+#' the regression coefficients.
+#'
 #' @return
 #' A \code{mixedSdfResults} object with the following elements:
 #'    \item{call}{the original call used in \code{mixed.sdf} }
 #'    \item{formula}{the formula used to fit the model}
-#'    \item{coef}{the estimates of the coefficients}
-#'    \item{se}{the standard error estimates of the coefficients}
-#'    \item{vars}{variance components of the model }
-#'    \item{levels}{the  number of levels in the model }
-#'    \item{ICC}{the intraclass correlation coefficient of the model }
+#'    \item{coef}{a vector of coefficient estimates}
+#'    \item{se}{a vector with the standard error estimates of the coefficients and the standard error of the variance components}
+#'    \item{vars}{estimated variance components of the model}
+#'    \item{levels}{the number of levels in the model}
+#'    \item{ICC}{the intraclass correlation coefficient of the model}
 #'    \item{npv}{the number of plausible values}
-#'    \item{ngroups}{a \code{data.frame} that includes number of observations for each group}
+#'    \item{ngroups}{a \code{data.frame} that includes the number of observations for each group}
+#'    \item{n0}{the number of observations in the original data}
+#'    \item{nused}{the number of observations used in the analysis}
 #' If the formula does not involve plausible values, the function will return the following additional elements:
 #'    \item{lnlf}{the likelihood function } 
 #'    \item{lnl}{the log-likelihood of the model }
@@ -86,25 +97,13 @@
 #'    \item{Vimp}{the estimated variance from uncertainty in the scores}
 #'    \item{Vjrr}{the estimated variance from sampling}
 #'    
-#' @details If users do not specify the \code{nQuad} argument, the functions will
-#'          use the \code{tolerance} argument to repeatedly run the mixed model and increment
-#'          \code{nQuad} (starting at 5) until the percentage of difference between the
-#'          log-likelihood of the new model and the old model is smaller than
-#'          \code{tolerance}. If users provide  \code{nQuad}, selecting a smaller value of \code{nQuad} 
-#'          can save processing time; however, it is recommended that users try incrementing
-#'            \code{nQuad} to check whether the result is stable.
-#'          
-#'          Note that if the outcome variable has plausible values, the previous setting will be 
-#'          applied to the estimation of all plausible values. 
-#' 
 #' @references 
 #' Rabe-Hesketh, S., & Skrondal, A. (2006). Multilevel modelling of complex
 #' survey data. \emph{Journal of the Royal Statistical Society: Series A
 #' (Statistics in Society), 169}(4), 805--827.
 #' 
-#' 
-#' @author Trang Nguyen and Claire Kelley
-#' @seealso \ifelse{latex}{\code{mix}}{\code{\link[WeMix]{mix}}} and \ifelse{latex}{\code{lm.sdf}}{\code{\link{lm.sdf}}}
+#' @author Paul Bailey, Trang Nguyen, and Claire Kelley
+#' @seealso \ifelse{latex}{WeMix \code{mix} function}{\code{\link[WeMix]{mix}}} and \code{\link{lm.sdf}}
 #' @example \man\examples\mixed.sdf.R
 #' @export
 #' @importFrom WeMix mix
@@ -125,15 +124,21 @@ mixed.sdf <- function(formula,
                       fast=FALSE,
                       ...) {
   call <- match.call()
+  # save this call
+  call0 <- call
   if(!missing(nQuad) & is.null(family)) {
-    warning(paste0("The ", sQuote("nQuad"), " argument is deprecated for linear models."))
+    warning(paste0("The ", sQuote("nQuad"), " argument is depreciated for linear models."))
   }
   if(!missing(tolerance) & is.null(family)) {
-    warning(paste0("The ", sQuote("tolerance"), " argument is deprecated."))
+    warning(paste0("The ", sQuote("tolerance"), " argument is depreciated."))
   }
   if(!missing(fast)) {
-    warning(paste0("The ", sQuote("fast"), " argument is deprecated."))
+    warning(paste0("The ", sQuote("fast"), " argument is depreciated."))
   }
+  if(!missing(family)) {
+    stop(paste0("The ", dQuote("family") ," argument is depreciated; plase use the ", dQuote("WeMix"), " package's ", dQuote("mix"), " function direclty for binomial models."))
+  }
+  formula0 <- formula
   # if users specify an edsurvey.data.frame or light.edsurvey.data.frame,
   # weightVars will be defined for each supported survey if not provided.
   # for each survey supported by edsurvey
@@ -174,7 +179,7 @@ mixed.sdf <- function(formula,
   # Get data
   getDataArgs <- list(data=data,
                       varnames=unique(c(all.vars(formula), weightVars, yvars)),
-                      returnJKreplicates=TRUE,
+                      returnJKreplicates=FALSE,
                       drop=FALSE,
                       omittedLevels=FALSE,
                       recode=recode,
@@ -268,8 +273,9 @@ mixed.sdf <- function(formula,
   # The standardization method varies across different surveys
   if (!weightTransformation) {
     # no weight transformations
-    edf$pwt1 <- edf[,weightVars[1]]
-    edf$pwt2 <- edf[,weightVars[2]]
+    for(wi in 1:length(weightVars)) {
+      edf[[paste0("pwt",wi)]] <- edf[,weightVars[wi]]
+    }
   } else {
     # weight transformations by survey
     if (survey == "PISA") {
@@ -323,21 +329,23 @@ mixed.sdf <- function(formula,
     #use summary to extract variances. 
     model_sum <- summary.WeMixResults(res)
     res$se <- c(model_sum$coef[,2] , model_sum$vars[,2])
+    names(res$se) <- c(row.names(model_sum$coef), row.names(model_sum$vars))
     res$vars <- model_sum$vars[,1]
-    
+    names(res$vars) <- row.names(model_sum$vars)
     # Remove some return values
     res$CMODE <- NULL 
     res$CMEAN <- NULL
     res$hessian <- NULL
-    
+    res$call <- call0
+    res$formula <- call0$formula
   } else { #run the plausible values version 
     #iterate through the plausible values 
     results <- list()
     variances <- list()
     pvi <- 0
     for (value in yvars){
-      if (verbose) {
-        cat("Estimation for ",value, " started.\n")
+      if (verbose>0) {
+        eout("Estimation for ",value, " started.")
       }
       pvi <- pvi+1
       
@@ -345,8 +353,8 @@ mixed.sdf <- function(formula,
       formula_pv <- update(formula_pv,as.formula(paste(value,"~.")))
       
       model <- withCallingHandlers(run_mix(nQuad=nQuad, call=call, formula=formula_pv,
-                                           edf=edf, verbose=verbose,family=family,center_group=centerGroup,center_grand=centerGrand,
-                                           tolerance=tolerance, fast=fast, ...),
+                                           edf=edf, verbose=verbose, family=family, center_group=centerGroup, center_grand=centerGrand,
+                                           tolerance=tolerance, ...),
                                    warning = function(w) {
                                      if (pvi != 1) { # only print the warning the first time
                                        invokeRestart("muffleWarning")
@@ -362,7 +370,10 @@ mixed.sdf <- function(formula,
       results[[value]] <- model 
       #use summary to extract variances
       model_sum <- summary.WeMixResults(model)
-      variances[[value]] <- c(model_sum$coef[,2]^2 , model_sum$vars[,2]^2)
+      variances[[value]] <- c(model_sum$coef[,"Std. Error"]^2 , model_sum$vars[,"Std. Error"]^2)
+      if(verbose > 0) {
+        print(model_sum)
+      }
     }
     res <- results[[1]]
     
@@ -372,15 +383,18 @@ mixed.sdf <- function(formula,
     res$CMODE <- NULL 
     res$CMEAN <- NULL
     res$hessian <- NULL
+    res$SE <- NULL
+    res$call <- call
+    res$PVresults <- results
     #get enrivonment of WeMix likelihood function to later extract covariance from
     env <- environment(results[[1]]$lnlf)
-    
     #Coefficients are just average value
     avg_coef <- rowSums(matrix(sapply(results,function(x){x$coef}),nrow=length(results[[1]]$coef)))/length(yvars)
     names(avg_coef) <- names(results[[1]]$coef)
       
-     #calcuate imputation variance for SEs and Residuals 
-    imputation_var <- ((length(yvars)+1)/((length(yvars)-1)*length(yvars))) * rowSums(matrix(sapply(results, function(x){x$coef - avg_coef})^2,nrow=length(avg_coef))) 
+    #calcuate imputation variance for SEs and Residuals 
+    M <- length(yvars)
+    imputation_var <- ((M+1)/((M-1)*M)) * rowSums(matrix(sapply(results, function(x){x$coef - avg_coef})^2,nrow=length(avg_coef))) 
     
     res$coef <- avg_coef
     #Variation in coefficients comes from imputation and also sampling 
@@ -389,7 +403,6 @@ mixed.sdf <- function(formula,
     
     #total se is sqrt of sampling + imputation variance
     res$se <- sqrt(sampling_var[1:length(imputation_var)] + imputation_var)
-    
     #ICC is mean ICC
     res$ICC <-  tryCatch(sum(sapply(results,function(x){x$ICC}))/length(yvars),
                          error=function(cond) {
@@ -397,40 +410,59 @@ mixed.sdf <- function(formula,
                          })
     
     #average residual variance
-    res$vars <-  rowSums(matrix(sapply(results,function(x){x$vars}), nrow = length(results[[1]]$vars)))/length(yvars)
+    res$vars <- rowSums(matrix(sapply(results,function(x){x$varDF$vcov}),
+                               nrow = nrow(results[[1]]$varDF)))/length(yvars)
     names(res$vars) <- names(results[[1]]$vars)
-    imputation_var_for_vars <- ((length(yvars)+1)/((length(yvars)-1)*length(yvars))) * rowSums(matrix(sapply(results, function(x){x$vars - res$vars})^2,nrow=length(res$vars))) 
-    names(imputation_var_for_vars) <- names(res$vars)
-    
+    # same thing for vcov
+    res$varDF$vcov <- res$vars
+    # get the var of var.
+    # 1, imputation is var of vars
+    imputation_var_for_vars <- ((M+1)/((M-1)*M)) *
+                                 apply(sapply(results,function(x){x$varDF$vcov}), 1, function(x) { sum((x - mean(x))^2)})
+    # 2, sampling is mean of var of vars
+    sampling_var_for_vars <- apply(sapply(results, function(x) {x$varDF$SEvcov^2}), 1, mean)
+    res$varDF$SEvcov <- sqrt(sampling_var_for_vars + imputation_var_for_vars)
     #Add on SE of residuals from sandwich estimator
-    res$se <-  c(res$se,sqrt(sampling_var[(length(imputation_var)+1):length(sampling_var)] + imputation_var_for_vars))
+    res$se <-  c(res$se,sqrt(sampling_var_for_vars + imputation_var_for_vars))
     
     res$Vimp <- c(imputation_var, imputation_var_for_vars)
-    res$Vjrr <- sampling_var
+    res$Vjrr <- c(sampling_var)
+    names(res$Vimp) <- names(res$Vjrr)
+    names(res$se) <- names(res$Vjrr)
+    # move formula to top
+    res$formula <- res$call$formula
   } #end if(pv)
 
-  
   res$npv <- length(yvars)
   res$n0 <- rawN
   res$nUsed <- nrow(edf)
   
-  #get group numbers 
+  #get group numbers, which is burried in the covariance matrix constructor (cConstructor)
   covCon <- get("cConstructor", env)
   lmeVarDf <- get("covMat", environment(covCon))
   lmeVarDf <- lmeVarDf[,c("grp","ngrp","level")]
   names(lmeVarDf) <- c("Group Var","Observations","Level")
   res$ngroups <- lmeVarDf
-  
+  # zero out things not needed
+  nullOut <- c("ranefs", "theta", "invHessian", "is_adaptive", "sigma", "cov_mat",
+               "varDF", "varVC", "var_theta", "PVresults", "SE")
+  for(ni in 1:length(nullOut)) {
+    res[[nullOut[ni]]] <- NULL
+  }
+
   class(res) <- "mixedSdfResults"
   return(res)
 }
 
 
-
 # helper function
 run_mix <- function(nQuad,call,formula,edf,verbose,tolerance,family,center_group,center_grand, fast, ...){
-  
   verboseAll <- ifelse(verbose==2,TRUE,FALSE) #set verbosity for WeMix to true if overall verbosity is 2
+  # linear models do not use nquad nor fast, drop those
+  if(is.null(family)) {
+    res <- mix(formula, data=edf, weights=c("pwt1","pwt2"), verbose = verboseAll, center_group=center_group, center_grand=center_grand, ...)
+    return(res)
+  }
   if (!is.null(nQuad)) {
     if(verbose > 0) {
       message(sQuote("nQuad"), " argument is specified so ", sQuote("tolerance"), " argument will not be used. It's recommended that users try incrementing ", sQuote("nQuad"), " to check whether the estimates are stable. ")
@@ -441,19 +473,18 @@ run_mix <- function(nQuad,call,formula,edf,verbose,tolerance,family,center_group
     return(res)
   } else {
     # specify a starting nQuad
-    nQuad <- 5
+    nQuad <- Inf
     diff <- Inf
     if (verbose>0) {
-      cat("Trying nQuad = ",nQuad,".\n") 
+      eout("Trying nQuad = ",nQuad,".") 
     }
     res0 <- mix(formula, data=edf, weights=c("pwt1","pwt2"), verbose = verboseAll, nQuad = nQuad,family=family,
                 center_group=center_group,center_grand=center_grand, fast=fast, ...)
 
-    #estimate0 <- c(coef(res0), res0$vars, res0$lnl)
     while(diff > tolerance) {
       nQuad <- nQuad + 2
       if (verbose>0) {
-        cat("Trying nQuad = ",nQuad,".\n") 
+        eout("Trying nQuad = ",nQuad,".") 
       }
       res <- mix(formula, data=edf, weights=c("pwt1","pwt2"), verbose = verboseAll, nQuad = nQuad,family=family,center_group=center_group,center_grand=center_grand, fast=fast, ...)
        # diff is the percentage difference of new lnl and old lnl
@@ -467,7 +498,6 @@ run_mix <- function(nQuad,call,formula,edf,verbose,tolerance,family,center_group
     class(res) <- "mixedSdfResults"
     return(res)
   } #end else if(!is.null(nQuad))
-  
 }
 
 
@@ -478,34 +508,41 @@ summary.mixedSdfResults <- function(object, ...) {
   #in the plausible values case there is no lnl and variance is already calcuated 
   object$coef <- cbind(Estimate=object$coef, "Std. Error"=object$se[1:length(object$coef)], "t value"=object$coef/object$se[1:length(object$coef)])
   object$vars <- cbind(variance=object$vars, "Std. Error"=object$se[-(1:nrow(object$coef))],"Std.Dev."=sqrt(object$vars))
-  
   class(object) <- "summary.mixedSdfResults"
-  object
+  return(object)
 }
 
 
 #' @method print summary.mixedSdfResults
 #' @export
 print.summary.mixedSdfResults <- function(x, ...) {
-  cat("Call:\n")
+  eout("Call:")
   print(x$call)
-  cat(paste0("\nFormula: ", paste(deparse(x$call$formula), collapse=""),"\n\n"))
+  cat("\n")
+  eout(paste0("Formula: ", paste(deparse(x$call$formula), collapse=""),"\n"))
 
   if(x$npv>1){
-    cat("\nPlausible Values: ",x$npv)
+    cat("\n")
+    eout(paste0("Plausible Values: ",x$npv))
   }
-  cat("\nNumber of Groups: \n")
+  eout("Number of Groups:")
   print(x$ngroups)
   
-  cat("\nVariance terms:\n")
+  cat("\n")
+  eout("Variance terms:")
   print(x$vars)
-  cat("\nFixed Effects:\n")
+  cat("\n")
+  eout("Fixed Effects:")
   printCoefmat(x$coef)
   if(x$npv==1){ #only print lnl if non plausible values case
-    cat("\nlnl=",format(x$lnl,nsmall=2),"\n")
+    cat("\n")
+    eout(paste0("lnl=",format(x$lnl,nsmall=2)))
   }
   if (!is.na(x$ICC)) {
-    cat("\nIntraclass Correlation=",format(x$ICC, nsmall=3, digits=3),"\n")
+    if(x$npv!=1) {
+      cat("\n")
+    } 
+    eout(paste0("Intraclass Correlation= ",format(x$ICC, nsmall=3, digits=3)))
   }
 }
 
