@@ -1,4 +1,3 @@
-# @importFrom data.table setDTthreads
 # @author Paul Bailey
 .onAttach <- function(libname, pkgname) {
   packageStartupMessage(paste0("EdSurvey v", utils::packageDescription("EdSurvey")$Version, "\n"))
@@ -7,4 +6,4 @@
 globalVariables(c("variable", "w", "c2", "dofNum", "dofDenom", "lengthY",
                   "sumY", "Percent", "wtdN", "N", "pcti", "value", "Vjrr",
                   "Vimp", "Level", "JKreplicate", "PV", "V1", "cnt_index",
-                  "w_lmi", "StandardError"))
+                  "w_lmi", "StandardError", "flag1"))
