@@ -2,26 +2,28 @@
 # read in the example data (generated, not real student data)
 sdf <- readNAEP(system.file("extdata/data", "M36NT2PM.dat", package = "NAEPprimer"))
 
-# By default uses jackknife variance method using replicate weights
+# by default uses jackknife variance method using replicate weights
 lm1 <- lm.sdf(composite ~ dsex + b017451, data=sdf)
 lm1
 
-# The summary function displays detailed results
+# the summary function displays detailed results
 summary(lm1)
 
-# To show standardized regression coefficients
+# to show standardized regression coefficients
 summary(lm1, src=TRUE)
 
-# To specify a variance method, use varMethod
+# to specify a variance method, use varMethod
 lm2 <- lm.sdf(composite ~ dsex + b017451, data=sdf, varMethod="Taylor")
 lm2
 summary(lm2)
 
-# Use relevel to set a new omitted category
+# use relevel to set a new omitted category
 lm3 <- lm.sdf(composite ~ dsex + b017451, data=sdf, relevels=list(dsex="Female"))
 summary(lm3)
+# test of a simple joint hypothesis
+waldTest(lm3, "b017451")
 
-# Use recode to change values for specified variables
+# use recode to change values for specified variables
 lm4 <- lm.sdf(composite ~ dsex + b017451, data=sdf,
               recode=list(b017451=list(from=c("Never or hardly ever",
                                               "Once every few weeks",
@@ -31,4 +33,5 @@ lm4 <- lm.sdf(composite ~ dsex + b017451, data=sdf,
                                        to=c("Frequently"))))
 # Note: "Infrequently" is the dropped level for the recoded b017451
 summary(lm4)
+
 }
