@@ -49,15 +49,15 @@ es3REF <- c("", "Formula: composite ~ lep + ell3 ", "", "Plausible values: 5",
 es4REF <- c("", "Formula: composite ~ lep + ell3 + dsex ", "", "Plausible values: 5", 
 "jrrIMax: 1", "Weight variable: 'origwt'", "Variance method: jackknife", 
 "JK replicates: 62", "full data n: 17606", "n used: 16910", "", 
-"", "Summary Table:", " lep         ell3   dsex    N     WTD_N      PCT   SE(PCT)     MEAN  SE(MEAN)", 
+"", "Summary Table:"," lep         ell3   dsex    N     WTD_N      PCT   SE(PCT)     MEAN  SE(MEAN)", 
 " Yes          Yes   Male  523  625.3030 53.23187 2.0754188 245.5156 3.0412906", 
 " Yes          Yes Female  451  549.3749 46.76813 2.0754188 239.3670 2.6004242", 
-" Yes           No   Male    0    0.0000      NaN        NA       NA        NA", 
-" Yes           No Female    0    0.0000      NaN        NA       NA        NA", 
-" Yes Formerly ELL   Male    0    0.0000      NaN        NA       NA        NA", 
-" Yes Formerly ELL Female    0    0.0000      NaN        NA       NA        NA", 
-"  No          Yes   Male    0    0.0000      NaN        NA       NA        NA", 
-"  No          Yes Female    0    0.0000      NaN        NA       NA        NA", 
+" Yes           No   Male    0    0.0000       NA        NA       NA        NA", 
+" Yes           No Female    0    0.0000       NA        NA       NA        NA", 
+" Yes Formerly ELL   Male    0    0.0000       NA        NA       NA        NA", 
+" Yes Formerly ELL Female    0    0.0000       NA        NA       NA        NA", 
+"  No          Yes   Male    0    0.0000       NA        NA       NA        NA", 
+"  No          Yes Female    0    0.0000       NA        NA       NA        NA", 
 "  No           No   Male 7828 7723.4302 50.12110 0.5013799 279.2644 0.8048072", 
 "  No           No Female 7842 7686.1070 49.87890 0.5013799 277.7026 0.9301768", 
 "  No Formerly ELL   Male  131  161.4708 46.62277 5.1070256 276.0706 3.2811027", 
@@ -117,12 +117,12 @@ es4tREF <- c("", "Formula: composite ~ lep + ell3 + dsex ", "", "Plausible value
 " lep         ell3   dsex    N     WTD_N      PCT   SE(PCT)     MEAN  SE(MEAN)", 
 " Yes          Yes   Male  523  625.3030 53.23187 1.9890178 245.5156 3.0903652", 
 " Yes          Yes Female  451  549.3749 46.76813 1.9890178 239.3670 2.4980995", 
-" Yes           No   Male    0    0.0000      NaN        NA       NA        NA", 
-" Yes           No Female    0    0.0000      NaN        NA       NA        NA", 
-" Yes Formerly ELL   Male    0    0.0000      NaN        NA       NA        NA", 
-" Yes Formerly ELL Female    0    0.0000      NaN        NA       NA        NA", 
-"  No          Yes   Male    0    0.0000      NaN        NA       NA        NA", 
-"  No          Yes Female    0    0.0000      NaN        NA       NA        NA", 
+" Yes           No   Male    0    0.0000       NA        NA       NA        NA", 
+" Yes           No Female    0    0.0000       NA        NA       NA        NA", 
+" Yes Formerly ELL   Male    0    0.0000       NA        NA       NA        NA", 
+" Yes Formerly ELL Female    0    0.0000       NA        NA       NA        NA", 
+"  No          Yes   Male    0    0.0000       NA        NA       NA        NA", 
+"  No          Yes Female    0    0.0000       NA        NA       NA        NA", 
 "  No           No   Male 7828 7723.4302 50.12110 0.5018499 279.2644 0.8304033", 
 "  No           No Female 7842 7686.1070 49.87890 0.5018499 277.7026 0.8980066", 
 "  No Formerly ELL   Male  131  161.4708 46.62277 3.2749498 276.0706 2.2525511", 
@@ -224,7 +224,7 @@ es5REF <- c("", "Formula: composite ~ dsex + b017451 + b003501 ", "", "Plausible
             " Female             Multiple Did not finish H.S.   0   0.0000   0.00000000          NA       NA        NA", 
             " Female             Multiple      Graduated H.S.   0   0.0000   0.00000000          NA       NA        NA", 
             " Female             Multiple  Some ed after H.S.   0   0.0000   0.00000000          NA       NA        NA", 
-            " Female             Multiple        I Don't Know   1   0.1435 100.00000000         NaN       NA        NA", 
+            " Female             Multiple        I Don't Know   1   0.1435 100.00000000          NA       NA        NA", 
             " Female             Multiple             Omitted   0   0.0000   0.00000000          NA       NA        NA", 
             " Female             Multiple            Multiple   0   0.0000   0.00000000          NA       NA        NA"
 )
@@ -295,12 +295,12 @@ logit1REF <- c("",
 gap0REF <- c("Call: gap(variable = \"b003501\", data = sdf, groupA = m815401 %in% \"Multiple\", ", 
              "    groupB = \"default\", targetLevel = \"Multiple\", omittedLevels = FALSE, ", 
              "    returnVarEstInputs = TRUE, returnSimpleDoF = TRUE, returnSimpleN = TRUE)", 
-             "", "labels:", " group              definition nFullData nUsed", 
+             "", "Labels:", " group              definition nFullData nUsed", 
              "     A m815401 %in% \"Multiple\"     17606    18", "     B                 default     17606 16915", 
-             "", "percentage:",
+             "", "Percentage:",
              "       pctA     pctAse     dofA pctB pctBse dofB    diffAB covAB   diffABse diffABpValue    dofAB", 
              " 0.09917399 0.03155192 12.84562  100      0    0 -99.90083     0 0.03155192            0 12.84562", 
-             "", "results:",
+             "", "Results:",
              " estimateA estimateAse dofA estimateB estimateBse     dofB     diffAB        covAB diffABse diffABpValue dofAB", 
              "         0          NA   NA 0.2195458  0.06638235 9.756959 -0.2195458 4.505231e-06       NA           NA    NA")
 
@@ -344,41 +344,47 @@ es_norhsREF <- c("", "Formula: composite ~ 1 ", "", "Plausible values: 5", "jrrI
                  "     N    WTD_N PCT     MEAN  SE(MEAN)",
                  " 16915 16932.46 100 275.8892 0.8217878")
 
-dplO <- c("", "Formula: composite - geometry ~ avg_5", "", "jrrIMax: 1", 
-          "Weight variable: 'origwt'", "Variance method: jackknife", "JK replicates: 62", 
-          "full data n: 17606", "n used: 15144", "", "Coefficients:",
-          "                   coef          se           t    dof  Pr(>|t|)    ", 
-          "(Intercept) -32.1895692   1.7984639 -17.8983687 58.289 < 2.2e-16 ***", 
-          "avg_5         0.1264752   0.0063834  19.8129915 53.390 < 2.2e-16 ***", 
+dplO <- c("",
+          "Formula: composite - geometry ~ avg_5", "",
+          "Weight variable: 'origwt'",
+          "Variance method: jackknife",
+          "JK replicates: 62", 
+          "Plausible values: 5",
+          "jrrIMax: 1", 
+          "full data n: 17606",
+          "n used: 15144", "",
+          "Coefficients:",
+          "                   coef          se       t    dof  Pr(>|t|)    ", 
+          "(Intercept) -32.1895692   1.7984639 -17.898 58.289 < 2.2e-16 ***", 
+          "avg_5         0.1264752   0.0063834  19.813 53.390 < 2.2e-16 ***", 
           "---", "Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1", 
           "", "Multiple R-squared: 0.113", "")
 
 gapPSUREF <- c("Call: gap(variable = \"composite\", data = sdf, groupA = dsex %in% \"Male\", ", 
                "    groupB = dsex %in% \"Female\", returnNumberOfPSU = TRUE)", 
-               "", "labels:",
+               "", "Labels:",
                " group         definition nFullData nUsed nPSU", 
                "     A   dsex %in% \"Male\"     17606  8486  124",
                "     B dsex %in% \"Female\"     17606  8429  124", "",
-               "percentage:",
+               "Percentage:",
                "     pctA    pctAse     pctB    pctBse    diffAB      covAB diffABse diffABpValue    dofAB", 
                " 50.27015 0.5016796 49.72985 0.5016796 0.5402935 -0.2516824 1.003359    0.5924778 53.45667", "",
-               "results:",
+               "Results:",
                " estimateA estimateAse estimateB estimateBse   diffAB     covAB  diffABse diffABpValue    dofAB", 
                "  276.7235   0.8207151  275.0458   0.9402535 1.677756 0.5676583 0.6498719   0.01259479 53.70969"
 )
 
 sPV_wREF <- c("Estimates are weighted using weight variable 'origwt'",
               "   Variable     N Weighted N    Min.  1st Qu.   Median     Mean  3rd Qu.    Max.       SD NA's Zero-weights", 
-              "1 composite 16915   16932.46 126.110 251.9620 277.4799 275.8892 301.1861 404.184 36.57022    0            0",
-              "2   algebra 16915   16932.46 109.842 254.7976 279.8315 278.9366 304.0191 412.152 36.65462    0            0")
+              "1 composite 16915   16932.46 126.110 251.9623 277.4784 275.8892 301.1835 404.184 36.57130    0            0", 
+              "2   algebra 16915   16932.46 109.842 254.7972 279.8320 278.9366 304.0195 412.152 36.65571    0            0")
 
 sPVREF <- c("Estimates are not weighted.", "  Variable     N   Min.  1st Qu. Median     Mean  3rd Qu.   Max.       SD NA's", 
             "1   mrpcm1 16915 130.53 252.0600 277.33 275.8606 300.7200 410.80 35.89864    0", 
             "2   mrpcm2 16915 124.16 252.2100 277.33 275.6399 300.6900 408.58 36.08483    0", 
             "3   mrpcm3 16915 115.09 252.0017 277.19 275.6570 300.5600 398.17 36.09278    0", 
             "4   mrpcm4 16915 137.19 252.4717 277.44 275.7451 300.5767 407.41 35.91078    0", 
-            "5   mrpcm5 16915 123.58 252.4900 277.16 275.6965 300.5000 395.96 36.10905    0"
-)
+            "5   mrpcm5 16915 123.58 252.4900 277.16 275.6965 300.5000 395.96 36.10905    0")
 
 sDiscrete_wREF <- c("Estimates are weighted using weight variable 'origwt'",
                     "                b017451   dsex Weighted N Weighted Percent Weighted Percent SE", 
@@ -403,7 +409,7 @@ sDiscreteREF <- c("Estimates are not weighted.",
                   "2 Female 8429   49.83")
 
 cor_nocondenseREF <- c("Method: Pearson", "full data n: 17606", "n used: 14816", "", 
-                       "Correlation: 0.1783484", "Correlation Levels:", "  Levels for Variable 'c046501' (Lowest level first):", 
+                       "Correlation: 0.1783484", "", "Correlation Levels:", "  Levels for Variable 'c046501' (Lowest level first):", 
                        "    1. 0%", "    2. 1-5%", "    3. 6-10%", "    4. 11-25%", 
                        "    5. 26-50%", "    8. Over 90%", "  Levels for Variable 'c044006' (Lowest level first):", 
                        "    1. None", "    2. 1-5%", "    3. 6-10%", "    4. 11-25%", 
@@ -433,3 +439,9 @@ logit2tREF <- c("", "Formula: iep ~ dsex + b013801", "Family: binomial (logit)",
                "b01380126-100  -0.22653   0.16072  -1.40948 47.152   0.1653    ", 
                "b013801>100     0.14767   0.21253   0.69482 29.369   0.4926    ", 
                "---", "Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1")
+
+assignTableREF <- structure(c(8486L, 0L, 0L, 8429L),
+                            .Dim = c(2L, 2L),
+                            .Dimnames = structure(list(c("Male", "Female"),
+                                                       c("Male", "Female")),
+                            .Names = c("", "")), class = "table")
